@@ -61,24 +61,35 @@ def flatten(
     csv=True,
     xlsx=False,
     sqlite=False,
+    parquet=False,
     dataframe=False,
-    path='',
+    path=[],
     main_table_name='main',
-    emit_path=[],
-    json_lines=False,
+    emit_obj=[],
+    ndjson=False,
+    json_stream=False,
     force=False,
-    fields='',
+    fields_csv='',
     only_fields=False,
-    tables='',
+    tables_csv='',
     only_tables=False,
     inline_one_to_one=False,
     schema="",
+    id_prefix="",
     table_prefix="",
     path_separator="_",
     schema_titles="",
     sqlite_path="",
     preview=0,
+    threads=1,
+    files=False,
     log_error=False,
+    postgres="",
+    postgres_schema="",
+    drop=False,
+    pushdown=[],
+    sql_scripts=False,
+    evolve=False,
 ):
     global LOGGING_SETUP
     if not LOGGING_SETUP:
@@ -88,8 +99,8 @@ def flatten(
     using_tmp = False
     
     if not output_dir:
-        if not dataframe:
-            raise AttributeError("Please set an `output_dir` or set `dataframe=True`")
+        if not dataframe and not sqlite_path and not postgres:
+            raise AttributeError("Please set an `output_dir` or set `dataframe=True` or `postgres` or `sqlite-db`")
         output_dir = tempfile.mkdtemp(prefix="flatterer-")
         force = True
         using_tmp = True
@@ -97,25 +108,42 @@ def flatten(
     if dataframe:
         csv = True
     
+    method = None
     try:
         try:
-            iter(input)
-            is_iterator = True
-        except typeError:
-            is_iterator = False
+            if isinstance(input, str):
+                method = 'flatten'
+                input = [input]
+            else:
+                iter(input)
+                if not files:
+                    method = 'iter'
+                else:
+                    input = list(input)
+                    method = 'flatten'
+        except TypeError:
+            input = [input]
+            method = 'flatten'
         
-        if isinstance(input, str):
-            flatten_rs(input, output_dir, csv, xlsx, sqlite,
-                    path, main_table_name, emit_path, json_lines, force, fields, only_fields, tables, 
-                    only_tables, inline_one_to_one, schema, table_prefix, path_separator, schema_titles, 
-                    sqlite_path, preview, log_error)
-        elif is_iterator:
+        if sqlite_path:
+            sqlite = True
+        
+        if method == 'flatten':
+            flatten_rs(input, output_dir, csv, xlsx, sqlite, parquet,
+                       main_table_name, tables_csv, only_tables, fields_csv, only_fields,
+                       inline_one_to_one, path_separator, preview, 
+                       table_prefix, id_prefix, emit_obj, force,  
+                       schema, schema_titles, path, json_stream, ndjson, 
+                       sqlite_path, threads, log_error, postgres, postgres_schema, drop, pushdown, sql_scripts, evolve)
+        elif method == 'iter':
             if path:
                 raise AttributeError("path not allowed when supplying an iterator")
-            iterator_flatten_rs(bytes_generator(input), output_dir, csv, xlsx, sqlite,
-                                main_table_name, emit_path, force, fields, only_fields, tables,
-                                only_tables, inline_one_to_one, schema, table_prefix, path_separator,
-                                schema_titles, sqlite_path, preview, log_error)
+            iterator_flatten_rs(bytes_generator(input), output_dir, csv, xlsx, sqlite, parquet,
+                       main_table_name, tables_csv, only_tables, fields_csv, only_fields,
+                       inline_one_to_one, path_separator, preview, 
+                       table_prefix, id_prefix, emit_obj, force,  
+                       schema, schema_titles, sqlite_path, threads, log_error, 
+                       postgres, postgres_schema, drop, pushdown, sql_scripts, evolve)
         else:
             raise AttributeError("input needs to be a string or a generator of strings, dicts or bytes")
 
@@ -155,11 +183,17 @@ def iterator_flatten(*args, **kw):
 @click.option('--csv/--nocsv', default=True, help='Output CSV files, default true')
 @click.option('--xlsx/--noxlsx', default=False, help='Output XLSX file, default false')
 @click.option('--sqlite/--nosqlite', default=False, help='Output sqlite.db file, default false')
+@click.option('--parquet/--noparquet', default=False, help='Output directory of parquet files, default false')
+@click.option('--postgres', default="", help='Connection string to postgres. If supplied will load data into postgres')
+@click.option('--sqlite-path', default="", help='Output sqlite file to this file')
+@click.option('--pushdown', '-d', multiple=True, help='Object keys and values, with this key name, will be copied down to child tables')
 @click.option('--main-table-name', '-m', default=None,
               help='Name of main table, defaults to name of the file without the extension')
 @click.option('--path', '-p', default='', help='Key name of where json array starts, default top level array')
-@click.option('--json-lines', '-j', is_flag=True, default=False,
-              help='Is file a jsonlines file, default false')
+@click.option('--ndjson', '-j', is_flag=True, default=False,
+              help='Is file a new line delemited JSON file, default false')
+@click.option('--json-stream', is_flag=True, default=False,
+              help='File contains stream of json object, default false')
 @click.option('--force', is_flag=True, default=False,
               help='Delete output directory if it exists, then run command, default False')
 @click.option('--fields', '-f', default="", help='fields.csv file to use')
@@ -178,17 +212,27 @@ def iterator_flatten(*args, **kw):
               help='Use titles from JSONSchema in the given way. Options are `full`, `slug`, `underscore_slug`. Default to not using titles')
 @click.option('--preview', '-w', default=0,
               help='Only output this `preview` amount of lines in final results')
+@click.option('--threads', default=1,
+              help='Number of threads, default 1, 0 means use number of CPUs')
+@click.option('--postgres-schema', default="", help='When loading to postgres, put all tables into this schema.')
+@click.option('--evolve', is_flag=True, default=False, help='When loading to postgres or sqlite, evolve tables to fit data')
+@click.option('--drop', is_flag=True, default=False, help='When loading to postgres or sqlite, drop table if already exists.')
+@click.option('--id-prefix', default="", help='Prefix for all `_link` id fields')
 @click.argument('input_file')
-@click.argument('output_directory')
+@click.argument('output_directory', required=False)
 def cli(
     input_file,
     output_directory,
     csv=True,
     xlsx=False,
     sqlite=False,
+    sqlite_path='',
+    parquet=False,
+    postgres='',
     path='',
     main_table_name=None,
-    json_lines=False,
+    ndjson=False,
+    json_stream=False,
     force=False,
     fields="",
     only_fields=False,
@@ -199,7 +243,13 @@ def cli(
     table_prefix="",
     path_separator="_",
     schema_titles="",
-    preview=0
+    preview=0,
+    threads=1,
+    postgres_schema="",
+    evolve=False,
+    drop=False,
+    pushdown=[],
+    id_prefix=""
 ):
     global LOGGING_SETUP
     if not LOGGING_SETUP:
@@ -209,6 +259,10 @@ def cli(
 
     if not main_table_name:
         main_table_name = input_file.split('/')[-1].split('.')[0]
+    
+    path_list = []
+    if path:
+        path_list.append(path)
 
     try:
         flatten(input_file,
@@ -216,13 +270,16 @@ def cli(
                 csv=csv,
                 xlsx=xlsx,
                 sqlite=sqlite,
-                path=path,
+                parquet=parquet,
+                postgres=postgres,
+                path=path_list,
                 main_table_name=main_table_name,
-                json_lines=json_lines,
+                ndjson=ndjson,
+                json_stream=json_stream,
                 force=force,
-                fields=fields,
+                fields_csv=fields,
                 only_fields=only_fields,
-                tables=tables,
+                tables_csv=tables,
                 only_tables=only_tables,
                 inline_one_to_one=inline_one_to_one,
                 schema=schema,
@@ -230,6 +287,13 @@ def cli(
                 path_separator=path_separator,
                 schema_titles=schema_titles,
                 preview=preview,
-                log_error=True)
+                threads=threads,
+                log_error=True,
+                postgres_schema=postgres_schema,
+                evolve=evolve,
+                drop=drop,
+                pushdown=pushdown,
+                id_prefix=id_prefix,
+                sqlite_path=sqlite_path)
     except IOError:
         pass
